local api = require("gemini.api")
local M = {}

-- Cache for completion items
local completion_cache = {}

-- Helper function to create completion items from Gemini response
local function parse_completion_response(response)
    if type(response) ~= "string" then
        return {}
    end
    
    -- Split response into lines and filter out empty ones
    local lines = vim.split(response, "\n")
    local items = {}
    
    for _, line in ipairs(lines) do
        if line and line:match("^%s*[^%s]") then -- Skip empty lines
            table.insert(items, {
                word = line:match("^%s*(.-)%s*$"), -- Trim whitespace
                kind = vim.lsp.protocol.CompletionItemKind.Text,
                menu = "[Gemini]",
                info = line,
            })
        end
    end
    
    -- Always return at least one item
    if #items == 0 then
        items = {
            { 
                word = "No completions found",
                kind = vim.lsp.protocol.CompletionItemKind.Text,
                menu = "[Gemini]"
            }
        }
    end
    
    return items
end

function M.get_completion(params, callback)
    local cursor = vim.api.nvim_win_get_cursor(0)
    local line = cursor[1]
    local col = cursor[2]
    
    -- Get current buffer content for context
    local lines = vim.api.nvim_buf_get_lines(0, math.max(0, line - 10), line, false)
    local prefix = table.concat(lines, "\n")
    
    -- Get current line up to cursor
    local current_line = vim.api.nvim_get_current_line()
    local before_cursor = string.sub(current_line, 1, col)
    
    -- Construct prompt for Gemini
    local prompt = string.format(
        "Complete this code. Only provide the completion, no explanation:\n%s\n%s",
        prefix,
        before_cursor
    )
    
    -- Get completion from Gemini
    api.get_response(prompt, nil, function(response, error)
        if error then
            callback({
                { 
                    word = "Error: " .. error,
                    kind = vim.lsp.protocol.CompletionItemKind.Text,
                    menu = "[Gemini]"
                }
            })
            return
        end
        
        local items = parse_completion_response(response)
        callback(items)
    end)
end

return M